@@ -70,21 +70,21 @@ def convert_py_float_to_cffi( x):
             px = np.ascontiguousarray( x, dtype = 'float64')
         else:
             # handle None
-           px = np.array( 0.0)
-           # pxcffi = ffi.cast( "double *", 0.0)            
+           px = np.array( 0.0)        
     pxcffi = ffi.cast( "double *", px.ctypes.data)
     return px, pxcffi
 
 
 def convert_py_int_to_cffi( x):
-    if x != None:
-        x = np.intc( x)
-        px = np.array( x)
-        pxcffi = ffi.cast( "int *", px.ctypes.data)
-    else: 
-        # handle None
-        px = np.array( 0)
-        pxcffi = ffi.cast( "int *", 0)
+    if isinstance( x, np.ndarray) == True:
+        px = np.ascontiguousarray( x, dtype = 'int32')
+    else:
+        if x != None:
+            px = np.ascontiguousarray( x, dtype = 'int32')
+        else:
+            # handle None
+           px = np.array( 0)        
+    pxcffi = ffi.cast( "int *", px.ctypes.data)
     return px, pxcffi
 
 # def convert_py_float_to_cffi( x):
